package main

import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material.*
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Delete
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.ExperimentalComposeUiApi
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.input.key.*
import androidx.compose.ui.unit.dp
import java.io.File

data class Project(val name: String)

fun loadProjects(): List<Project> {
    val projectsDirectory = File("src/main/resources/projects/")

    return projectsDirectory.listFiles()?.map { Project(it.name) } ?: emptyList()
}

@Composable
fun projectsPage(
    currentPage: MutableState<String>
) {
    val appState = AppState
    var projects: List<Project> by remember { mutableStateOf(loadProjects()) }

    Column(
        modifier = Modifier.fillMaxSize(),
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Text("Sélectionnez un projet", style = MaterialTheme.typography.h5)

        Spacer(modifier = Modifier.height(16.dp))

        LazyColumn(
            modifier = Modifier
                .padding(10.dp)
                .width(200.dp)
                .height(300.dp),
            verticalArrangement = Arrangement.spacedBy(10.dp)
        ) {
            if (projects.isEmpty()) {
                item {
                    Text("Aucun projet n'a été créé")
                }
            } else {
                items(projects, key = { project -> project.name }) { project ->
                    Row(
                        modifier = Modifier.width(200.dp).fillMaxWidth(),
                        horizontalArrangement = Arrangement.SpaceBetween
                    ) {
                        Button(
                            onClick = {
                                appState.selectedProject = project
                                currentPage.value = "glossaires"

                            },
                            modifier = Modifier
                                .width(150.dp),
                            colors = ButtonDefaults.buttonColors(
                                backgroundColor = customRedColor,
                                contentColor = Color.White
                            )
                        ) {
                            Text(project.name)
                        }

                        IconButton(
                            onClick = {
                                // Handle delete project action
                                projects = projects.filterNot { it.name == project.name }
                                println(projects)
                                val directory = File("src/main/resources/projects/${project.name}/")
                                directory.deleteRecursively()
                                currentPage.value = "projects"
                            }
                        ) {
                            Icon(imageVector = Icons.Default.Delete, contentDescription = "Delete Project")
                        }
                    }
                }
            }
        }

        Spacer(modifier = Modifier.height(16.dp))

        Button(
            onClick = {
                currentPage.value = "nouveauProjet"
            },
            modifier = Modifier
                .width(300.dp),
            colors = ButtonDefaults.buttonColors(
                backgroundColor = customRedColor,
                contentColor = Color.White
            )
        ) {
            Text("Créer un nouveau projet")
        }

        Spacer(modifier = Modifier.height(6.dp))

        Button(
            onClick = {
                currentPage.value = "accueil"
            },
            modifier = Modifier
                .width(250.dp),
            colors = ButtonDefaults.buttonColors(
                backgroundColor = customRedColor,
                contentColor = Color.White
            )
        ) {
            Text("Retour")
        }
    }
}

@OptIn(ExperimentalComposeUiApi::class)
@Composable
fun newProject(
    currentPage: MutableState<String>
){
    var projectName by remember { mutableStateOf("") }

    val isEmptySnackbarVisibleState = remember { mutableStateOf(false) }
    val containsSpaceSnackbarVisibleState = remember { mutableStateOf(false) }
    val glossaryAlreadyExistsSnackbarVisibleState = remember { mutableStateOf(false) }
    val invalidCharacterSnackbarVisibleState = remember { mutableStateOf(false) }

    Column(
        modifier = Modifier.fillMaxSize(),
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally
    ){
        Text("Nom du projet", style = MaterialTheme.typography.h5)

        Spacer(modifier = Modifier.height(16.dp))
        val projectsList = loadProjects()

        TextField(
            value = projectName,
            singleLine = true,
            onValueChange = { projectName = it },
            label = { Text("Nom du projet") },
            colors = TextFieldDefaults.textFieldColors(
                focusedIndicatorColor = customRedColor,
                unfocusedIndicatorColor = Color.Gray,
                focusedLabelColor = customRedColor
            ),
            modifier = Modifier
                .width(300.dp)
                .fillMaxWidth()
                .onKeyEvent { event ->
                    if (event.key == Key.Enter && event.type == KeyEventType.KeyDown) {
                        if (projectName.isEmpty()) {
                            println("Veuillez saisir un nom pour le nouveau projet")
                            isEmptySnackbarVisibleState.value = true
                        } else if (projectName.contains(" ")) {
                            println("Le nom du projet ne doit pas contenir d'espace")
                            containsSpaceSnackbarVisibleState.value = true
                        } else if (projectsList.any { it.name == projectName }) {
                            println("Le nom du projet existe déjà")
                            glossaryAlreadyExistsSnackbarVisibleState.value = true
                        } else if (!isValidFileName(projectName)) {
                            println("Le nom du projet contient des caractères non autorisés")
                            invalidCharacterSnackbarVisibleState.value = true
                        } else {
                            val directory = File("src/main/resources/projects/$projectName/")
                            directory.mkdirs()
                            println("Project $projectName created")
                            currentPage.value = "projects"
                        }
                        true
                    } else {
                        false
                    }
                }
        )

        Spacer(modifier = Modifier.height(16.dp))

        Button(
            onClick = {
                if (projectName.isEmpty()) {
                    println("Veuillez saisir un nom pour le nouveau projet")
                    isEmptySnackbarVisibleState.value = true
                } else if (projectName.contains(" ")) {
                    println("Le nom du projet ne doit pas contenir d'espace")
                    containsSpaceSnackbarVisibleState.value = true
                } else if (projectsList.any { it.name == projectName }) {
                    println("Le nom du projet existe déjà")
                    glossaryAlreadyExistsSnackbarVisibleState.value = true
                } else if (!isValidFileName(projectName)) {
                    println("Le nom du projet contient des caractères non autorisés")
                    invalidCharacterSnackbarVisibleState.value = true
                } else {
                    val directory = File("src/main/resources/projects/$projectName/")
                    directory.mkdirs()
                    println("Project $projectName created")
                    currentPage.value = "projects"
                }
            },
            modifier = Modifier
                .width(300.dp),
            colors = ButtonDefaults.buttonColors(
                backgroundColor = customRedColor,
                contentColor = Color.White
            )
        ) {
            Text("Créer")
        }

        Spacer(modifier = Modifier.height(6.dp))

        Button(
            onClick = {
                currentPage.value = "projects"
            },
            modifier = Modifier
                .width(250.dp),
            colors = ButtonDefaults.buttonColors(
                backgroundColor = customRedColor,
                contentColor = Color.White
            )
        ) {
            Text("Retour")
        }

        if (isEmptySnackbarVisibleState.value) {
            Snackbar(
                modifier = Modifier.padding(16.dp),
                action = {
                    Button(
                        onClick = { isEmptySnackbarVisibleState.value = false },
                        colors = ButtonDefaults.buttonColors(
                            backgroundColor = customRedColor,
                            contentColor = Color.White
                        )
                    ) {
                        Text("OK")
                    }
                }
            ) {
                Text("Veuillez entrer un nom de projet.")
            }
        }
        if (containsSpaceSnackbarVisibleState.value) {
            Snackbar(
                modifier = Modifier.padding(16.dp),
                action = {
                    Button(
                        onClick = { containsSpaceSnackbarVisibleState.value = false },
                        colors = ButtonDefaults.buttonColors(
                            backgroundColor = customRedColor,
                            contentColor = Color.White
                        )
                    ) {
                        Text("OK")
                    }
                }
            ) {
                Text("Veuillez ne pas mettre d'espace dans le nom du projet.")
            }
        }
        if (glossaryAlreadyExistsSnackbarVisibleState.value) {
            Snackbar(
                modifier = Modifier.padding(16.dp),
                action = {
                    Button(
                        onClick = { glossaryAlreadyExistsSnackbarVisibleState.value = false },
                        colors = ButtonDefaults.buttonColors(
                            backgroundColor = customRedColor,
                            contentColor = Color.White
                        )
                    ) {
                        Text("OK")
                    }
                }
            ) {
                Text("Ce projet existe déjà.")
            }
        }
        if (invalidCharacterSnackbarVisibleState.value) {
            Snackbar(
                modifier = Modifier.padding(16.dp),
                action = {
                    Button(
                        onClick = { invalidCharacterSnackbarVisibleState.value = false },
                        colors = ButtonDefaults.buttonColors(
                            backgroundColor = customRedColor,
                            contentColor = Color.White
                        )
                    ) {
                        Text("OK")
                    }
                }
            ) {
                Text("Le nom du projet contient des caractères non autorisés (caractères spéciaux).")
            }
        }
    }
}




